"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _Popover = _interopRequireDefault(require("./Popover"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const DEFAULT_LAYOUT = {
  width: 0,
  height: 0,
  x: 0,
  y: 0
};

var _default = ({
  action = 'press',
  animated,
  animationType,
  backgroundColor,
  children,
  caret,
  caretPosition,
  content,
  numberOfLines,
  onAction,
  position = 'top',
  strictPosition = false,
  style,
  visible
}) => {
  const dimensions = (0, _reactNative.useWindowDimensions)();
  const [popoverVisible, setPopoverVisible] = (0, _react.useState)(false);
  const [popoverOffset, setPopoverOffset] = (0, _react.useState)({
    left: 0,
    top: 0
  });
  const [popoverLayout, setPopoverLayout] = (0, _react.useState)(DEFAULT_LAYOUT);
  const [childrenLayout, setChildrenLayout] = (0, _react.useState)(DEFAULT_LAYOUT);
  const [computedPosition, setComputedPosition] = (0, _react.useState)(position);
  const isInteractive = typeof visible === 'undefined';
  const childrenRef = (0, _react.useRef)(null);
  const popoverRef = (0, _react.useRef)(null);
  const handlers = {};

  if (isInteractive) {
    if (action === 'hover') {
      handlers.onHoverIn = () => {
        setPopoverVisible(true);
        onAction === null || onAction === void 0 ? void 0 : onAction(true);
      };

      handlers.onHoverOut = () => {
        setPopoverVisible(false);
        onAction === null || onAction === void 0 ? void 0 : onAction(false);
      };
    } else if (action === 'press') {
      handlers.onPress = () => {
        setPopoverVisible(visible => {
          onAction === null || onAction === void 0 ? void 0 : onAction(!visible);
          return !visible;
        });
      };
    } else {
      handlers.onLongPress = () => {
        setPopoverVisible(visible => {
          onAction === null || onAction === void 0 ? void 0 : onAction(!visible);
          return !visible;
        });
      };
    }
  }

  const handlePopoverLayout = (0, _react.useCallback)(() => {
    var _popoverRef$current;

    (_popoverRef$current = popoverRef.current) === null || _popoverRef$current === void 0 ? void 0 : _popoverRef$current.measureInWindow((x, y, width, height) => {
      setPopoverLayout({
        x,
        y,
        width,
        height
      });
    });
  }, [popoverRef]);
  const handleChildrenLayout = (0, _react.useCallback)(() => {
    var _childrenRef$current;

    (_childrenRef$current = childrenRef.current) === null || _childrenRef$current === void 0 ? void 0 : _childrenRef$current.measureInWindow((x, y, width, height) => {
      setChildrenLayout({
        x,
        y,
        width,
        height
      });
    });
  }, [childrenRef]);
  (0, _react.useEffect)(() => {
    let nextPosition = position;

    if (!strictPosition) {
      switch (position) {
        case 'left':
          if (popoverLayout.x <= 0) {
            nextPosition = 'right';
          }

          break;

        case 'right':
          if (popoverLayout.x + popoverLayout.width > dimensions.width) {
            nextPosition = 'left';
          }

          break;

        case 'top':
          if (popoverLayout.y <= 0) {
            nextPosition = 'bottom';
          }

          break;

        case 'bottom':
          if (popoverLayout.y + popoverLayout.height >= dimensions.height) {
            nextPosition = 'top';
          }

          break;
      }
    }

    setComputedPosition(nextPosition);
  }, [position, strictPosition, popoverLayout, childrenLayout, dimensions]);
  (0, _react.useEffect)(() => {
    let left = 0;
    let top = 0;

    switch (computedPosition) {
      case 'right':
      case 'left':
        top = (popoverLayout.height - childrenLayout.height) / 2;
        break;

      case 'top':
      case 'bottom':
        left = (popoverLayout.width - childrenLayout.width) / 2;
        break;
    }

    setPopoverOffset({
      left,
      top
    });
  }, [computedPosition, popoverLayout, childrenLayout]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.container
  }, /*#__PURE__*/_react.default.createElement(_Popover.default, {
    ref: popoverRef,
    animated: animated,
    animationType: animationType,
    backgroundColor: backgroundColor,
    caret: caret,
    caretPosition: caretPosition,
    numberOfLines: numberOfLines,
    onLayout: handlePopoverLayout,
    position: computedPosition,
    visible: isInteractive ? popoverVisible : visible,
    style: [computedPosition === 'top' && styles.popoverTop, computedPosition === 'bottom' && styles.popoverBottom, computedPosition === 'left' && {
      alignItems: 'flex-end',
      right: childrenLayout.width
    }, computedPosition === 'right' && {
      left: childrenLayout.width
    }, {
      position: 'absolute',
      transform: [{
        translateX: popoverOffset.left * -1
      }, {
        translateY: popoverOffset.top * -1
      }]
    }, style]
  }, content), /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, _extends({
    ref: childrenRef,
    onLayout: handleChildrenLayout
  }, handlers), children));
};

exports.default = _default;

const styles = _reactNative.StyleSheet.create({
  container: {
    position: 'relative',
    zIndex: 1
  },
  popoverTop: {
    bottom: '100%'
  },
  popoverBottom: {
    top: '100%'
  }
});
//# sourceMappingURL=Popable.js.map